#
# spec file for package ibus-libzhuyin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ibus-libzhuyin
Version:        1.10.3
Release:        1.6
Summary:        Zhuyin engine based on libzhuyin for IBus
License:        GPL-2.0-only
Group:          System/I18n/Chinese
URL:            https://github.com/libzhuyin/ibus-libzhuyin
Source:         https://github.com/libzhuyin/ibus-libzhuyin/releases/download/%{version}/ibus-libzhuyin-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  gnome-common
BuildRequires:  intltool
BuildRequires:  libpinyin-tools >= 2.0.91
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(ibus-1.0) >= 1.4.99
BuildRequires:  pkgconfig(libpinyin) >= 2.2.0
BuildRequires:  pkgconfig(opencc) >= 1.0.0
Provides:       locale(ibus:zh_TW;zh_HK)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package includes a Chinese Zhuyin (Bopomofo) input method based
on libzhuyin for IBus.

%prep
%setup -q
#NOCONFIGURE=1 ./autogen.sh

%build
%configure --libexecdir=%{_ibus_libexecdir}
make %{?_smp_mflags}

%install
%make_install

rm -rf %{buildroot}%{_datadir}/doc
%find_lang %{name}
%fdupes %{buildroot}

%files -f %{name}.lang
%defattr(-,root,root)
%doc AUTHORS ChangeLog README
%license COPYING
%{_ibus_libexecdir}/ibus-engine-libzhuyin
%{_ibus_libexecdir}/ibus-setup-libzhuyin
%{_datadir}/%{name}
%{_libdir}/ibus-libzhuyin/
%{_datadir}/metainfo/*.appdata.xml
%{_datadir}/ibus/component/libzhuyin.xml
%{_datadir}/applications/ibus-setup-libzhuyin.desktop
%{_datadir}/glib-2.0/schemas/com.github.libzhuyin.ibus-libzhuyin.gschema.xml

%changelog
* Sun Apr 28 2024 jun wang <jgwang@suse.com>
- Update to version 1.10.3
  * configure.ac (AM_GNU_GETTEXT_VERSION): Bump to 0.21
  * Fix processKeyEvent methods
  * Update libzhuyin.appdata.xml
* Sat Jan 20 2024 Callum Farmer <gmbr3@opensuse.org>
- Fixes for %%_ibus_libexecdir moving to %%_libexecdir (bsc#1174075)
* Wed Mar  8 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Do not BuildRequire libzhuyin13: that's the responsibility of the
  respective devel package.
* Sun Jan 22 2023 Dirk Müller <dmueller@suse.com>
- update to 1.10.2:
  * bug fixes
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 1.10.1:
  * fix setup dialog
* Mon Mar  1 2021 Marguerite Su <i@marguerite.su>
- update version 1.10.0
  * use database_format and model13.text.tar.gz
* Wed Oct  9 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.9.1
  * fixed page up and page down shortcut key
  * fixed special symbols
  * fixed escape handling
  * fixed numpad
  * fixed special symbol
  * add need-tone option
* Tue Oct 23 2018 hillwood@opensuse.org
- Update version to 1.8.92
  * fixes easy symbol and user symbol
  * update read method
  * use model11.text.tar.gz
  * translate input method name in ibus menu
  * fixes cursor move
  * fixes application shortcut issue
  * fixes numpad issue
* Sun Oct  1 2017 hillwood@opensuse.org
- Update to 1.8.0
  * fixes processCommit method.
  * clean code.
  * fixes a warning.
- Use libpinyin 2.1.0
- Remove invalid %%post and %%postun.
* Sat Aug 26 2017 jengelh@inai.de
- Trim time-sensitive wording in summary.
* Tue Aug 22 2017 hillwood@opensuse.org
- Update to 1.7.91
  * merge libzhuyin data.
* Tue Aug 22 2017 hillwood@opensuse.org
- Update to 1.7.10
  * fix issue 31 - full width punctuation input with wrong symbol
  * fix issue 32 - full/half width shortcut key switch with extra space output
  * fix issue 33 - fixes full/half width symbol input problem
* Sat Sep 10 2016 hillwood@opensuse.org
- Update to 1.7.8
  * fixes leak
  * Fixes FallbackEditor
  * fixes full punctuation in English mode
  * use Shift-Space to toggle full English mode
  * update class ZhuyinProperties
  * update class ZhuyinConfig
  * update main.py
  * update setup UI
  * combine two full/width modes into one mode
  * fixes compile
* Fri Dec 25 2015 hillwood@linuxfans.org
- Update to 1.7.6
  * clean up getCursorRight method
  * fixes getCursorRight and selectCandidate method
  * fixes getCursorRight method
  * fixes probe_section_start function
  * fixes getCursorRight method
  * fixes processSpace method
  * fixes prepareCandidates method
* Thu Oct  8 2015 hillwood@linuxfans.org
- fix file list.
* Sun Aug 23 2015 i@marguerite.su
- update version 1.7.4
  * add option - "Use Space Key to Show Candidates".
  * add option - "Show Candidates After the Cursor".
  * use zhuyin_valid_zhuyin_keys method.
- changes in 1.7.1
  * migrate setup dialog to python 3.x.
  * support gnome-software.
- drop ibus-libzhuyin-opencc-1_0_2-build.patch, upstreamed
* Wed Feb 25 2015 hillwood@linuxfans.org
- Use opencc 1.0.2
  * add ibus-libzhuyin-opencc-1_0_2-build.patch
* Sun Nov  2 2014 hillwood@linuxfans.org
- Update to 1.6.99.20140929
  * write updateLookupTableLabel method
* Sun Jul 13 2014 i@marguerite.su
- initial version 1.6.99.20140626
